==> mojave-5.17.1.tgz: package/url/LocalRouter.js <==
import { parse, stringify } from "query-string";
import { on } from "../dom/events";
import { extend } from "../extend";
function normalizeParams(params, normalizers) {
    const result = {};
    for (const key in normalizers) {
        if ("route" === key) {
            continue;
        }
        const value = params[key];
        try {
            result[key] = normalizers[key](value);
        }
        catch (e) {
            throw new Error(`Missing / invalid value for param '${key}': ${e.message}`);
        }
    }
    return result;
}
function generateQueryString(route, params) {
    return "?" + stringify(extend({ route }, params), {
        skipNull: true,
        skipEmptyString: true,
        sort: (left, right) => {
            if (left === "route") {
                return -1;
            }
            if (right === "route") {
                return 1;
            }
            if (left === right) {
                return 0;
            }
            return left < right ? -1 : 1;
        },
    });
}
function parseQueryString(queryString) {
    return parse(queryString, { parseNumbers: true });
}
export class LocalRouter {
    constructor(updateUrl = true) {
        this.collection = {};
        this.useUrl = updateUrl;
    }
    on(name, handler, normalizers) {
        if (this.collection[name]) {
            throw new Error("Can't define two routes with the same name.");
        }
        if ("route" in normalizers) {
            throw new Error("Can't use 'route' as route parameter");
        }
        this.collection[name] = { handler, normalizers };
        return this;
    }
    init(fallbackRoute, fallbackParams = {}) {
        const fallback = this.collection[fallbackRoute];
        if (!fallback) {
            throw new Error(`Invalid initialization: there is no route named '${fallbackRoute}'`);
        }
        if (this.useUrl) {
            on(window, "popstate", () => this.match(document.location.search));
            if (this.match(document.location.search)) {
                return;
            }
        }
        fallback.handler(normalizeParams(fallbackParams, fallback.normalizers));
    }
    navigate(route, params = {}) {
        const definition = this.collection[route];
        if (!definition) {
            throw new Error(`Route not found: ${route}`);
        }
        const normalized = normalizeParams(params, definition.normalizers);
        definition.handler(normalized);
        if (this.useUrl && normalized) {
            window.history.pushState(params, document.title, generateQueryString(route, normalized));
        }
    }
    match(queryString) {
        const params = parseQueryString(queryString);
        const route = params.route;
        if (typeof route !== "string") {
            return false;
        }
        const definition = this.collection[route];
        if (!definition) {
            return false;
        }
        try {
            definition.handler(normalizeParams(params, definition.normalizers));
            return true;
        }
        catch (_a) {
            return false;
        }
    }
}

==> mojave-5.20.1.tgz: package/url/LocalRouter.js <==
import { parse, stringify } from "query-string";
import { on } from "../dom/events";
import { extend } from "../extend";
function normalizeParams(params, normalizers) {
    const result = {};
    for (const key in normalizers) {
        if ("route" === key) {
            continue;
        }
        const value = params[key];
        try {
            result[key] = normalizers[key](value);
        }
        catch (e) {
            throw new Error(`Missing / invalid value for param '${key}': ${e.message}`);
        }
    }
    return result;
}
function generateQueryString(route, params) {
    const existingParameters = parseQueryString(document.location.search);
    return "?" + stringify(extend(existingParameters, { route }, params), {
        skipNull: true,
        skipEmptyString: true,
        sort: (left, right) => {
            if (left === "route") {
                return -1;
            }
            if (right === "route") {
                return 1;
            }
            if (left === right) {
                return 0;
            }
            return left < right ? -1 : 1;
        },
    });
}
function parseQueryString(queryString) {
    return parse(queryString, { parseNumbers: true });
}
export class LocalRouter {
    constructor(updateUrl = true) {
        this.collection = {};
        this.useUrl = updateUrl;
    }
    on(name, handler, normalizers) {
        if (this.collection[name]) {
            throw new Error("Can't define two routes with the same name.");
        }
        if ("route" in normalizers) {
            throw new Error("Can't use 'route' as route parameter");
        }
        this.collection[name] = { handler, normalizers };
        return this;
    }
    init(fallbackRoute, fallbackParams = {}) {
        const fallback = this.collection[fallbackRoute];
        if (!fallback) {
            throw new Error(`Invalid initialization: there is no route named '${fallbackRoute}'`);
        }
        if (this.useUrl) {
            on(window, "popstate", () => this.match(document.location.search));
            if (this.match(document.location.search)) {
                return;
            }
        }
        fallback.handler(normalizeParams(fallbackParams, fallback.normalizers));
    }
    navigate(route, params = {}) {
        const definition = this.collection[route];
        if (!definition) {
            throw new Error(`Route not found: ${route}`);
        }
        const normalized = normalizeParams(params, definition.normalizers);
        definition.handler(normalized);
        if (this.useUrl && normalized) {
            window.history.pushState(params, document.title, generateQueryString(route, normalized));
        }
    }
    match(queryString) {
        const params = parseQueryString(queryString);
        const route = params.route;
        if (typeof route !== "string") {
            return false;
        }
        const definition = this.collection[route];
        if (!definition) {
            return false;
        }
        try {
            definition.handler(normalizeParams(params, definition.normalizers));
            return true;
        }
        catch (_a) {
            return false;
        }
    }
}
